.. asttokens documentation master file, created by
   sphinx-quickstart on Sat Dec 10 13:00:48 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

ASTTokens Documentation
=======================

The ``asttokens`` module annotates Python abstract syntax trees (ASTs) with the positions of tokens
and text in the source code that generated them. This is helpful for tools that make source code
transformations.

.. toctree::
    :maxdepth: 2

    user-guide
    api-index

License
-------
Copyright 2016, Grist Labs, Inc. Licensed under the Apache License, Version 2.0.

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
